import ApiService from '@/utils/api';

interface UserInfo {
  id: number;
  nickname: string;
  accountName: string;
}

interface ApiResponse<T> {
  code: number;
  data?: T;
  message?: string;
}

export async function getUserInfo(): Promise<ApiResponse<UserInfo>> {
  try {
    const token = localStorage.getItem('token');
    if (!token) {
      return {
        code: 401,
        message: '未登录或token无效'
      };
    }

    return await ApiService.get<UserInfo>('/users/info');
  } catch (error) {
    console.error('获取用户信息失败:', error);
    return {
      code: 500,
      message: '网络请求失败'
    };
  }
} 